# gdbyvgt - Gradient Descent by Gia Tue Vu

This library implements **Gradient Descent** for Machine Learning.
It is simple and easy to use, especially for Linear Regression.
This library is mainly for beginners.
This is also my very first library. Hope you enjoy it.
## Installation

```sh
pip install gdbyvgt
